.. ETLPlus documentation master file, created by
   sphinx-quickstart on Sun Mar  8 22:07:16 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ETLPlus documentation
=====================

ETLPlus is a veritable Swiss Army knife for enabling simple ETL operations,
offering both a Python package and command-line interface for data extraction,
validation, transformation, and loading. This site publishes getting-started
material, workflow guides, release notes, and an API reference generated from
the ``etlplus`` package docstrings so the published docs track the Python
source.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting-started/index
   guides/index
   api/index
   changelog
